﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.Linq;
using System.Data.Linq.Mapping;


namespace linq02
{
    class Program
    {
        static void Main(string[] args)
        {
            using (IntroDotNet db = new IntroDotNet(@"Data Source=(localDB)\V11.0;AttachDbFilename=|DataDirectory|\introdotnet.mdf;Integrated Security=True"))
            {
                db.Log = Console.Out;
                DateTime refDatum = new DateTime(); ;
                IQueryable<Auteur> query = from aut in db.Auteur
                                           where aut.GebDatum > refDatum
                                           select aut;
                refDatum = new DateTime(1950, 1, 1);
                Console.WriteLine("===Auteurs geboren na 1 januari 1950:");
                foreach (Auteur a in query)
                {
                    Console.WriteLine("{0}:{1}({2:d})", a.AuteurId, a.Naam, a.GebDatum);
                }
                refDatum = new DateTime(1900, 1, 1);
                Console.WriteLine("\n===Auteurs geboren na 1 januari 1900:");
                foreach (Auteur a in query)
                {
                    Console.WriteLine("{0}:{1}({2:d})", a.AuteurId, a.Naam, a.GebDatum);
                }
                var duurQuery = from b in db.Boek
                                where b.Prijs > 10
                                select b;
                Console.WriteLine("\n===Alle boeken die duurder zijn dan 10 EUR:");
                foreach (Boek a in duurQuery)
                {
                    Console.WriteLine("{0}:{1}({2})", a.Auteur.Naam, a.Titel, a.Prijs);
                }
            }
        }
    }
    [Table(Name="Auteur")]
    public class Auteur
    {
        private int auteurId;
        [Column(IsPrimaryKey=true,Storage="auteurId")]
        public int AuteurId
        {
            get { return auteurId; }
            set { auteurId = value; }
        }
        private String naam;
        [Column(Storage="naam")]
        public String Naam
        {
            get { return naam; }
            set { naam = value; }
        }
        private DateTime gebDatum;
        [Column(Storage="gebDatum")]
        public DateTime GebDatum
        {
            get { return gebDatum; }
            set { gebDatum = value; }
        }
        private EntitySet<Boek> boeken;
        [Association(Storage="boeken",OtherKey="Auteurid")]
        public EntitySet<Boek> Boeken
        {
            get { return boeken; }
            set { boeken.Assign(value); }
        }
        public Auteur()
        {
            boeken = new EntitySet<Boek>();
        }

    }
    [Table(Name="Boek")]
    public class Boek
    {
        private int bookid=0;
        [Column(Storage="bookid",IsDbGenerated=true,IsPrimaryKey=true)]
        public int Bookid
        {
            get { return bookid; }
        }
        private String titel;
        [Column(Storage="titel")]
        public String Titel
        {
            get { return titel; }
            set { titel = value; }
        }
        private int oplage;
        [Column(Storage="oplage")]
        public int Oplage
        {
            get { return oplage; }
            set { oplage = value; }
        }
        private decimal prijs;
        [Column(Storage="prijs")]
        public decimal Prijs
        {
            get { return prijs; }
            set { prijs = value; }
        }
        private EntityRef<Auteur> auteur;
        [Association(Storage="auteur",ThisKey="Auteurid")]
        public Auteur Auteur
        {
            get { return auteur.Entity; }
            set { auteur.Entity = value; }
        }
        private int auteurid;
        [Column(Storage="auteurid")]
        public int Auteurid
        {
            get { return auteurid; }
            set { auteurid = value; }
        }
        
        public Boek()
        {
            auteur = new EntityRef<Auteur>();
        }
    }
    public class IntroDotNet : DataContext
    {
        public Table<Auteur> Auteur;
        public Table<Boek> Boek;
        public IntroDotNet(String connectie)
            : base(connectie)
        {
        }
    }
}
